@@ -21,17 +21,16 @@
 
 #include "searchhandler.h"
 
-#include "searchengine.h"
-#include "prefs.h"
 #include "docentry.h"
+#include "khc_debug.h"
 
 #include <KDesktopFile>
 #include <KProcess>
-#include <KMessageBox>
 #include <KShell>
 #include <KLocalizedString>
+#include <kio/job.h>
 
-#include <stdlib.h>
+#include <prefs.h>
 
 using namespace KHC;
 
@@ -150,7 +149,7 @@ ExternalProcessSearchHandler::ExternalProcessSearchHandler( const KConfigGroup &
   mSearchBinary = QStandardPaths::findExecutable(mSearchBinary, searchBinaryPaths);
 }
 
-QString ExternalProcessSearchHandler::indexCommand( const QString &identifier )
+QString ExternalProcessSearchHandler::indexCommand( const QString &identifier ) const
 {
   QString cmd = mIndexCommand;
   cmd.replace( "%i", identifier );
@@ -194,13 +193,13 @@ void ExternalProcessSearchHandler::search( DocEntry *entry, const QStringList &w
   int maxResults,
   SearchEngine::Operation operation )
 {
-  qDebug() << entry->identifier();
+  khcDebug() << entry->identifier();
 
   if ( !mSearchCommand.isEmpty() ) {
     QString cmdString = SearchEngine::substituteSearchQuery( mSearchCommand,
       entry->identifier(), words, maxResults, operation, mLang, mSearchBinary );
 
-    qDebug() << "CMD:" << cmdString;
+    khcDebug() << "CMD:" << cmdString;
 
     SearchJob *searchJob = new SearchJob(entry);
     connect(searchJob, SIGNAL(searchFinished( SearchJob *, DocEntry *, const QString & )),
@@ -213,7 +212,7 @@ void ExternalProcessSearchHandler::search( DocEntry *entry, const QStringList &w
     QString urlString = SearchEngine::substituteSearchQuery( mSearchUrl,
       entry->identifier(), words, maxResults, operation, mLang, mSearchBinary );
 
-    qDebug() << "URL:" << urlString;
+    khcDebug() << "URL:" << urlString;
 
     SearchJob *searchJob = new SearchJob(entry);
     connect(searchJob, SIGNAL(searchFinished( SearchJob *, DocEntry *, const QString & )),
